grpc

package
v0.0.0-...-ac7c41d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 19, 2026 License: 0BSD Imports: 6 Imported by: 0

Documentation

Overview

Package protowire parses and formats the raw wire encoding. See https://protobuf.dev/programming-guides/encoding.

For marshaling and unmarshaling entire protobuf messages, use the google.golang.org/protobuf/proto package instead.

Index

Constants

const (
	MinValidNumber        wireNumber = 1
	FirstReservedNumber   wireNumber = 19000
	LastReservedNumber    wireNumber = 19999
	MaxValidNumber        wireNumber = 1<<29 - 1
	DefaultRecursionLimit            = 10000
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Encoder

type Encoder struct {
	// contains filtered or unexported fields
}

Encoder for the GRPC Protocol Buffers format

func NewEncoder

func NewEncoder(w io.Writer) *Encoder

func (*Encoder) Encode

func (e *Encoder) Encode(v any) error

Jump to